@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class DynDatatablesConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
-    name = 'apps.dyn_datatables'
+    name = 'django_dyn_dt'
